@@ -6,47 +6,103 @@ use warnings;
 
 =head1 NAME
 
-IMDB::Local::Director - The great new IMDB::Local::Director!
+IMDB::Local::Director - Object representation of Director information.
 
 =head1 VERSION
 
-Version 0.01
+Version 1.00
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '1.00';
 
 
 =head1 SYNOPSIS
 
-Quick summary of what the module does.
-
-Perhaps a little code snippet.
-
-    use IMDB::Local::Director;
-
-    my $foo = IMDB::Local::Director->new();
-    ...
-
 =head1 EXPORT
 
-A list of functions that can be exported.  You can delete this section
-if you don't export anything, such as for a purely object-oriented module.
-
 =head1 SUBROUTINES/METHODS
 
 =head2 function1
 
 =cut
 
-sub function1 {
+use IMDB::Local::DB::BaseObject;
+use base qw(IMDB::Local::DB::BaseObject);
+
+use constant DB_TABLE => 'Directors';
+use constant DB_KEY   => 'DirectorID';
+
+use Class::MethodMaker
+    [ 
+      scalar => [DB_KEY],
+      array => [qw/ -static db_columns/],
+      new  => [qw/ -init -hash new/] ,
+    ];
+
+sub init($)
+{
+    my ($self)=@_;
+
+    # static array needs to be initialized only if it isn't already
+    #if ( !$self->db_ignoredColumns_count ) {
+    #$self->db_ignoredColumns_push(DB_COLUMNS_IGNORE);
+    #}
+
+    $self->initHandle(DB_TABLE, DB_KEY);
+
+    if ( $self->populateUsingKey($self->get(DB_KEY)) ) {
+	return $self;
+    }
+    return(undef);
 }
 
-=head2 function2
+use Carp;
 
-=cut
+sub createNew($%)
+{
+    my ($imdbdb, %args)=@_;
 
-sub function2 {
+    carp("no name given") if ( !defined($args{name}) );
+
+    my $id=$imdbdb->insert_db(DB_TABLE, DB_KEY, %args);
+    if ( !defined($id) ) {
+	return(undef);
+    }
+    return new IMDB::Local::Director(imdbdb=>$imdbdb, TableID=>$id);
+}
+
+sub findByDirectorID($$)
+{
+    my ($imdbdb, $id)=@_;
+    return new IMDB::Local::Director(imdbdb=>$imdbdb, DB_KEY, $id);
+}
+
+sub findByName($$)
+{
+    my ($imdbdb, $name)=@_;
+
+    my $id=$imdbdb->select2Scalar("SELECT ".DB_KEY." from ".DB_TABLE." where name='$name'");
+    if ( defined($id) ) {
+	return new IMDB::Local::Director(imdbdb=>$imdbdb, DB_KEY, $id);
+    }
+    return(undef);
+}
+
+sub getIDs($$)
+{
+    my ($class, $imdbdb)=@_;
+    my @ids;
+
+    my $res=$imdbdb->dbh->selectall_arrayref("SELECT ".DB_KEY." FROM ".DB_TABLE." ORDER BY ".DB_KEY."");
+    if ( !defined($res) ) {
+	return(@ids);
+    }
+
+    for my $list (@$res) {
+	push(@ids, $list->[0]);
+    }
+    return(@ids);
 }
 
 =head1 AUTHOR
@@ -60,8 +116,6 @@ the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=IMDB-Local
 automatically be notified of progress on your bug as I make changes.
 
 
-
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
